<!DOCTYPE html>
<html xmlns:t="http://twistedmatrix.com/ns/twisted.web.template/0.1">
  <head>
    <title>
      API Documentation for
      <t:transparent t:render="project">Some Project</t:transparent>
    </title>
    <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
    <link rel="stylesheet" type="text/css" href="bootstrap.min.css" />
    <link rel="stylesheet" type="text/css" href="apidocs.css" />
  </head>
  <body>

    <nav class="navbar navbar-default">
      <div class="container">

        <div class="navbar-header">
          <a class="navbar-brand" href="index.html">
            <t:transparent t:render="project">Some Project</t:transparent> API Documentation
          </a>
        </div>
      </div>
    </nav>

    <div class="container">
      <h2>
        Get Started
      </h2>
      <ul>
        <li>
          A listing of <a href="moduleIndex.html">all modules and
          packages</a>, organized by package hierarchy.
        </li>
        <li>
          A listing of <a href="classIndex.html">all classes</a>,
          organized by inheritance hierarchy.
        </li>
        <li>
          A listing of <a href="nameIndex.html">all functions, classes,
          modules and packages</a>, ordered by name.
        </li>
        <li t:render="recentChanges">
          See <a href="recentChanges">recent changes</a> made online to
          docstrings.
        </li>
        <li t:render="problemObjects">
          See <a href="problemObjects">objects with formatting problems</a>.
        </li>
        <li t:render="onlyIfOneRoot">
          Start at <a href="root.html">root</a>, the root package.
        </li>
        <t:transparent t:render="onlyIfMultipleRoots">
          <li>
            Or start at one of the root <t:transparent t:render="rootkind">
            packages</t:transparent>:
            <ul>
              <li t:render="roots">
                <t:slot name="root"/>
              </li>
            </ul>
          </li>
        </t:transparent>
      </ul>
      <h2>
        About
      </h2>
      <p>
        This documentation was automatically generated by
        <a href="https://github.com/twisted/pydoctor/">pydoctor</a>
        at <t:transparent t:render="buildtime">some
          time</t:transparent>.
      </p>

    </div>

  </body>
</html>
